==> eiffelstudio-18.11.10.2592.tar: F_code/C5/ew242.c <==
/*
 * Code for class EW_COMPILE_FINAL_KEEP_INST
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ew242.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {EW_COMPILE_FINAL_KEEP_INST}.compilation_options */
static EIF_REFERENCE F761_4267_body (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
#define Result RTOTRR
	RTOUDR(217)

	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("compilation_options", 760, Current, 0, 1, 9017);
	RTGC;
	RTOTP;
	RTHOOK(1);
	{
		static EIF_TYPE_INDEX typarr0[] = {645,894,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 645, _OBJSIZ_1_1_0_1_0_0_0_0_);
	}
	F646_3682(RTCW(tr1), ((EIF_INTEGER_32) 2L));
	Result = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	tr1 = RTMS32_EX_H("-\000\000\000v\000\000\000e\000\000\000r\000\000\000b\000\000\000o\000\000\000s\000\000\000e\000\000\000",8,1123198821);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R2579[Dtype(Result)-509])(RTCW(Result), tr1);
	RTHOOK(3);
	tr1 = RTMS32_EX_H("-\000\000\000f\000\000\000i\000\000\000n\000\000\000a\000\000\000l\000\000\000i\000\000\000z\000\000\000e\000\000\000",9,1727329893);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R2579[Dtype(Result)-509])(RTCW(Result), tr1);
	RTHOOK(4);
	tr1 = RTMS32_EX_H("-\000\000\000k\000\000\000e\000\000\000e\000\000\000p\000\000\000",5,1802152816);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R2579[Dtype(Result)-509])(RTCW(Result), tr1);
	RTOTE;
	RTHOOK(5);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F761_4267 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	return RTOUCR(217,F761_4267_body,(Current,arg1));
}

void EIF_Minit242 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C5/ew242.c <==
/*
 * Code for class EW_COMPILE_FINAL_KEEP_INST
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ew242.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {EW_COMPILE_FINAL_KEEP_INST}.compilation_options */
static EIF_REFERENCE F761_4274_body (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
#define Result RTOTRR
	RTOUDR(217)

	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("compilation_options", 760, Current, 0, 1, 9024);
	RTGC;
	RTOTP;
	RTHOOK(1);
	{
		static EIF_TYPE_INDEX typarr0[] = {645,894,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 645, _OBJSIZ_1_1_0_1_0_0_0_0_);
	}
	F646_3689(RTCW(tr1), ((EIF_INTEGER_32) 2L));
	Result = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	tr1 = RTMS32_EX_H("-\000\000\000v\000\000\000e\000\000\000r\000\000\000b\000\000\000o\000\000\000s\000\000\000e\000\000\000",8,1123198821);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R2581[Dtype(RTCW(Result))-625])(Result, tr1);
	RTHOOK(3);
	tr1 = RTMS32_EX_H("-\000\000\000f\000\000\000i\000\000\000n\000\000\000a\000\000\000l\000\000\000i\000\000\000z\000\000\000e\000\000\000",9,1727329893);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R2581[Dtype(RTCW(Result))-625])(Result, tr1);
	RTHOOK(4);
	tr1 = RTMS32_EX_H("-\000\000\000k\000\000\000e\000\000\000e\000\000\000p\000\000\000",5,1802152816);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R2581[Dtype(RTCW(Result))-625])(Result, tr1);
	RTOTE;
	RTHOOK(5);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F761_4274 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	return RTOUCR(217,F761_4274_body,(Current,arg1));
}

void EIF_Minit242 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
